@@ -15,6 +15,7 @@ from matplotlib.figure import Figure
 from matplotlib.font_manager import FontProperties
 import matplotlib.patches as mpatches
 import matplotlib.pyplot as plt
+from matplotlib.gridspec import GridSpec
 import matplotlib.transforms as mtransforms
 from matplotlib.testing.decorators import check_figures_equal, image_comparison
 from matplotlib.testing._markers import needs_usetex
@@ -707,9 +708,13 @@ def test_large_subscript_title():
      (0.3, 0, 'right'),
      (0.3, 185, 'left')])
 def test_wrap(x, rotation, halign):
-    fig = plt.figure(figsize=(6, 6))
+    fig = plt.figure(figsize=(18, 18))
+    gs = GridSpec(nrows=3, ncols=3, figure=fig)
+    subfig = fig.add_subfigure(gs[1, 1])
+    # we only use the central subfigure, which does not align with any
+    # figure boundary, to ensure only subfigure boundaries are relevant
     s = 'This is a very long text that should be wrapped multiple times.'
-    text = fig.text(x, 0.7, s, wrap=True, rotation=rotation, ha=halign)
+    text = subfig.text(x, 0.7, s, wrap=True, rotation=rotation, ha=halign)
     fig.canvas.draw()
     assert text._get_wrapped_text() == ('This is a very long\n'
                                         'text that should be\n'
@@ -916,7 +921,7 @@ def test_annotate_offset_fontsize():
                         fontsize='10',
                         xycoords='data',
                         textcoords=text_coords[i]) for i in range(2)]
-    points_coords, fontsize_coords = [ann.get_window_extent() for ann in anns]
+    points_coords, fontsize_coords = (ann.get_window_extent() for ann in anns)
     fig.canvas.draw()
     assert str(points_coords) == str(fontsize_coords)
 
